package sun.security.jgss.spi;

import com.sun.security.jgss.InquireType;
import org.ietf.jgss.MessageProp;
import java.io.OutputStream;
import java.io.InputStream;
import org.ietf.jgss.Oid;
import org.ietf.jgss.ChannelBinding;
import org.ietf.jgss.GSSException;
import java.security.Provider;

public interface GSSContextSpi
{
    public abstract Provider getProvider();
    
    public abstract void requestLifetime(int p0) throws GSSException;
    
    public abstract void requestMutualAuth(boolean p0) throws GSSException;
    
    public abstract void requestReplayDet(boolean p0) throws GSSException;
    
    public abstract void requestSequenceDet(boolean p0) throws GSSException;
    
    public abstract void requestCredDeleg(boolean p0) throws GSSException;
    
    public abstract void requestAnonymity(boolean p0) throws GSSException;
    
    public abstract void requestConf(boolean p0) throws GSSException;
    
    public abstract void requestInteg(boolean p0) throws GSSException;
    
    public abstract void requestDelegPolicy(boolean p0) throws GSSException;
    
    public abstract void setChannelBinding(ChannelBinding p0) throws GSSException;
    
    public abstract boolean getCredDelegState();
    
    public abstract boolean getMutualAuthState();
    
    public abstract boolean getReplayDetState();
    
    public abstract boolean getSequenceDetState();
    
    public abstract boolean getAnonymityState();
    
    public abstract boolean getDelegPolicyState();
    
    public abstract boolean isTransferable() throws GSSException;
    
    public abstract boolean isProtReady();
    
    public abstract boolean isInitiator();
    
    public abstract boolean getConfState();
    
    public abstract boolean getIntegState();
    
    public abstract int getLifetime();
    
    public abstract boolean isEstablished();
    
    public abstract GSSNameSpi getSrcName() throws GSSException;
    
    public abstract GSSNameSpi getTargName() throws GSSException;
    
    public abstract Oid getMech() throws GSSException;
    
    public abstract GSSCredentialSpi getDelegCred() throws GSSException;
    
    public abstract byte[] initSecContext(InputStream p0, int p1) throws GSSException;
    
    public abstract byte[] acceptSecContext(InputStream p0, int p1) throws GSSException;
    
    public abstract int getWrapSizeLimit(int p0, boolean p1, int p2) throws GSSException;
    
    public abstract void wrap(InputStream p0, OutputStream p1, MessageProp p2) throws GSSException;
    
    public abstract byte[] wrap(byte[] p0, int p1, int p2, MessageProp p3) throws GSSException;
    
    public abstract void unwrap(InputStream p0, OutputStream p1, MessageProp p2) throws GSSException;
    
    public abstract byte[] unwrap(byte[] p0, int p1, int p2, MessageProp p3) throws GSSException;
    
    public abstract void getMIC(InputStream p0, OutputStream p1, MessageProp p2) throws GSSException;
    
    public abstract byte[] getMIC(byte[] p0, int p1, int p2, MessageProp p3) throws GSSException;
    
    public abstract void verifyMIC(InputStream p0, InputStream p1, MessageProp p2) throws GSSException;
    
    public abstract void verifyMIC(byte[] p0, int p1, int p2, byte[] p3, int p4, int p5, MessageProp p6) throws GSSException;
    
    public abstract byte[] export() throws GSSException;
    
    public abstract void dispose() throws GSSException;
    
    public abstract Object inquireSecContext(InquireType p0) throws GSSException;
}
